@@ -27,15 +27,19 @@ from . utils import (_split_choices,
                      _split_choices_in_list_canc,
                      _successivo_ad_oggi)
 
-
-try:
-    from filesig.filesig import get_signatures
-except:
-    from filesig import get_signatures
-
-
 logger = logging.getLogger(__name__)
 
+get_signatures = None
+try:
+    from filesig.filesig import get_signatures
+except Exception as e:
+    logger.error('Error: {}'.format(e))
+
+if not get_signatures:
+    try:
+        from filesig import get_signatures
+    except Exception as e:
+        logger.error('Error: {}'.format(e))
 
 
 MAX_UPLOAD_SIZE = getattr(settings, 'MAX_UPLOAD_SIZE', MAX_UPLOAD_SIZE)
@@ -250,9 +254,10 @@ class CustomSignedFileField(CustomFileField):
     def get_cleaned_signature_params(self, data):
         res = self.get_signature_params(data)
         details = {}
-        details['Signature Validation'] = res[-1].get('Signature Validation')
-        details['Signing Time'] = res[-1].get('Signing Time')
-        details['Signer full Distinguished Name'] = res[-1].get('Signer full Distinguished Name')
+        if res:
+            details['Signature Validation'] = res[-1].get('Signature Validation')
+            details['Signing Time'] = res[-1].get('Signing Time')
+            details['Signer full Distinguished Name'] = res[-1].get('Signer full Distinguished Name')
         return details
 
     def raise_error(self, name, cleaned_data, **kwargs):
@@ -272,10 +277,10 @@ class CustomSignedPdfField(CustomSignedFileField):
     """
     field_type = _("Allegato PDF firmato")
     fileformat = 'pdf'
+    valid_extensions = PDF_FILETYPE
 
-    def __init__(self, *args, **data_kwargs):
-        self.valid_extensions = PDF_FILETYPE
-        super().__init__(*args, **data_kwargs)
+    #def __init__(self, *args, **data_kwargs):
+        #super().__init__(*args, **data_kwargs)
 
 
 class CustomSignedP7MField(CustomSignedFileField):
@@ -283,10 +288,10 @@ class CustomSignedP7MField(CustomSignedFileField):
     """
     field_type = _("Allegato P7M firmato")
     fileformat = 'p7m'
+    valid_extensions = P7M_FILETYPE
 
-    def __init__(self, *args, **data_kwargs):
-        self.valid_extensions = P7M_FILETYPE
-        super().__init__(*args, **data_kwargs)
+    #def __init__(self, *args, **data_kwargs):
+        #super().__init__(*args, **data_kwargs)
 
 
 class PositiveIntegerField(DecimalField, BaseCustomField):
@@ -567,10 +572,11 @@ class CaptchaField(BaseCustomField):
 
     def define_value(self, custom_value, **kwargs):
         self.widget = CaptchaWidget(attrs={'value': custom_value,
-                                           'hidden_field': kwargs['hidden_field']})
+                                           'hidden_field': kwargs.get('hidden_field', ''),
+                                           'lang': kwargs.get('lang', 'en')})
 
 
-class CustomCaptchaComplexField(BaseCustomField):
+class CustomCaptchaComplexField(CaptchaField):
     """
     Captcha
 
@@ -605,10 +611,17 @@ class CustomCaptchaComplexField(BaseCustomField):
         self.captcha_hidden.parent = self
         self.captcha_hidden.label = ''
 
+        # TODO
+        # questo perchè viene nel constructor dict mentre dovrebbe venire nel custom_params ...
+        lang = 'en'
+        if kwargs.get('lang'):
+            lang = kwargs.pop('lang')
+
         self.captcha = CaptchaField(*args, **kwargs)
         self.captcha.required = True
         self.captcha.define_value(custom_value=text,
-                                  hidden_field="id_{}".format(self.captcha_hidden.name))
+                                  hidden_field="id_{}".format(self.captcha_hidden.name),
+                                  lang=lang)
         self.captcha.label = parent_label
         self.captcha.name = captcha_name or "{}_dyn".format(format_field_name(parent_label))
         # this should be taken from constructore dict
